@@ -636,7 +636,10 @@ get_info (ProcData *procdata, gint pid)
 	else
 		info->arguments = g_strdup ("");
 	
-	info->user = g_strdup_printf ("%s", pwd->pw_name);
+	if (pwd->pw_name)
+		info->user = g_strdup_printf ("%s", pwd->pw_name);
+	else
+		info->user = NULL;
 	info->mem = procmem.size;
 	info->vmsize = procmem.vsize;
 	info->memres = procmem.resident;
